/* global jQuery */
/* jshint globalstrict: true */
"use strict";

if (typeof jQuery === "undefined") {
    throw new Error("jQuery is required");
}

(function($) {
    $.fn.showBootstrapAlertSuccess = function(message, contentType, dissmisable, timeout) {
        return this.showBootstrapAlert({
            message: message,
            contentType: contentType,
            alertType: Bootstrap.AlertType.Success,
            dissmisable: dissmisable,
            timeout: timeout
        });
    };
    $.fn.showBootstrapAlertDanger = function(message, contentType, dissmisable, timeout) {
        return this.showBootstrapAlert({
            message: message,
            contentType: contentType,
            alertType: Bootstrap.AlertType.Danger,
            dissmisable: dissmisable,
            timeout: timeout
        });
    };
    $.fn.showBootstrapAlertWarning = function(message, contentType, dissmisable, timeout) {
        return this.showBootstrapAlert({
            message: message,
            contentType: contentType,
            alertType: Bootstrap.AlertType.Warning,
            dissmisable: dissmisable,
            timeout: timeout
        });
    };
    $.fn.showBootstrapAlertInfo = function(message, contentType, dissmisable, timeout) {
        return this.showBootstrapAlert({
            message: message,
            contentType: contentType,
            alertType: Bootstrap.AlertType.Info,
            dissmisable: dissmisable,
            timeout: timeout
        });
    };
    $.fn.showBootstrapAlert = function(options) {
        var settings = $.extend({
            message: null,
            alertType: Bootstrap.AlertType.None,
            contentType: Bootstrap.ContentType.Text,
            dissmisable: false,
            timeout: 0
        }, options);
        return this.each(function() {
            var ref = $(this);
            ref.empty();
            ref.removeClass();
            var closeBtn = null;
            $(this).addClass(settings.alertType.Background);
            if (settings.dissmisable) {
                closeBtn = $("<button></button>").prop("type", "button").prop("aria-hidden", true).html("&times;").addClass("close").click(function() {
                    ref.hide(200);
                });
                $(this).append(closeBtn);
            }
            if (settings.timeout > 0) {
                setTimeout(function() {
                    ref.hide(200);
                }, settings.timeout);
            }
            var icon = $("<span></span>").prop("aria-hidden", true).addClass(settings.alertType.Icon);
            var alert = $("<div></div>").css("display", "inline").css("margin-left", "5px");
            switch (settings.contentType) {
              case Bootstrap.ContentType.Html:
                alert.html(settings.message).find("a").addClass("alert-link");
                break;

              case Bootstrap.ContentType.Text:
                alert.text(settings.message);
                break;
            }
            $(this).append(icon);
            $(this).append(alert);
            $(this).show();
        });
    };
})(jQuery);

var Bootstrap = {
    AlertType: {
        None: {
            Background: "",
            Icon: ""
        },
        Success: {
            Background: "alert alert-success",
            Icon: "glyphicon glyphicon-ok"
        },
        Info: {
            Background: "alert alert-info",
            Icon: "glyphicon glyphicon-info-sign"
        },
        Warning: {
            Background: "alert alert-warning",
            Icon: "glyphicon glyphicon-alert"
        },
        Danger: {
            Background: "alert alert-danger",
            Icon: "glyphicon glyphicon-exclamation-sign"
        }
    },
    ContentType: {
        Html: "html",
        Text: "text"
    },
    GlyphIcon: {
        Asterisk: "glyphicon glyphicon-asterisk",
        Plus: "glyphicon glyphicon-plus",
        Euro: "glyphicon glyphicon-euro",
        Eur: "glyphicon glyphicon-eur",
        Minus: "glyphicon glyphicon-minus",
        Cloud: "glyphicon glyphicon-cloud",
        Envelope: "glyphicon glyphicon-envelope",
        Pencil: "glyphicon glyphicon-pencil",
        Glass: "glyphicon glyphicon-glass",
        Music: "glyphicon glyphicon-music",
        Search: "glyphicon glyphicon-search",
        Heart: "glyphicon glyphicon-heart",
        Star: "glyphicon glyphicon-star",
        StarEmpty: "glyphicon glyphicon-star-empty",
        User: "glyphicon glyphicon-user",
        Film: "glyphicon glyphicon-film",
        ThLarge: "glyphicon glyphicon-th-large",
        Th: "glyphicon glyphicon-th",
        ThList: "glyphicon glyphicon-th-list",
        Ok: "glyphicon glyphicon-ok",
        Remove: "glyphicon glyphicon-remove",
        ZoomIn: "glyphicon glyphicon-zoom-in",
        ZoomOut: "glyphicon glyphicon-zoom-out",
        Off: "glyphicon glyphicon-off",
        Signal: "glyphicon glyphicon-signal",
        Cog: "glyphicon glyphicon-cog",
        Trash: "glyphicon glyphicon-trash",
        Home: "glyphicon glyphicon-home",
        File: "glyphicon glyphicon-file",
        Time: "glyphicon glyphicon-time",
        Road: "glyphicon glyphicon-road",
        DownloadAlt: "glyphicon glyphicon-download-alt",
        Download: "glyphicon glyphicon-download",
        Upload: "glyphicon glyphicon-upload",
        Inbox: "glyphicon glyphicon-inbox",
        PlayCircle: "glyphicon glyphicon-play-circle",
        Repeat: "glyphicon glyphicon-repeat",
        Refresh: "glyphicon glyphicon-refresh",
        ListAlt: "glyphicon glyphicon-list-alt",
        Lock: "glyphicon glyphicon-lock",
        Flag: "glyphicon glyphicon-flag",
        Headphones: "glyphicon glyphicon-headphones",
        VolumeOff: "glyphicon glyphicon-volume-off",
        VolumeDown: "glyphicon glyphicon-volume-down",
        VolumeUp: "glyphicon glyphicon-volume-up",
        Qrcode: "glyphicon glyphicon-qrcode",
        Barcode: "glyphicon glyphicon-barcode",
        Tag: "glyphicon glyphicon-tag",
        Tags: "glyphicon glyphicon-tags",
        Book: "glyphicon glyphicon-book",
        Bookmark: "glyphicon glyphicon-bookmark",
        Print: "glyphicon glyphicon-print",
        Camera: "glyphicon glyphicon-camera",
        Font: "glyphicon glyphicon-font",
        Bold: "glyphicon glyphicon-bold",
        Italic: "glyphicon glyphicon-italic",
        TextHeight: "glyphicon glyphicon-text-height",
        TextWidth: "glyphicon glyphicon-text-width",
        AlignLeft: "glyphicon glyphicon-align-left",
        AlignCenter: "glyphicon glyphicon-align-center",
        AlignRight: "glyphicon glyphicon-align-right",
        AlignJustify: "glyphicon glyphicon-align-justify",
        List: "glyphicon glyphicon-list",
        IndentLeft: "glyphicon glyphicon-indent-left",
        IndentRight: "glyphicon glyphicon-indent-right",
        FacetimeVideo: "glyphicon glyphicon-facetime-video",
        Picture: "glyphicon glyphicon-picture",
        MapMarker: "glyphicon glyphicon-map-marker",
        Adjust: "glyphicon glyphicon-adjust",
        Tint: "glyphicon glyphicon-tint",
        Edit: "glyphicon glyphicon-edit",
        Share: "glyphicon glyphicon-share",
        Check: "glyphicon glyphicon-check",
        Move: "glyphicon glyphicon-move",
        StepBackward: "glyphicon glyphicon-step-backward",
        FastBackward: "glyphicon glyphicon-fast-backward",
        Backward: "glyphicon glyphicon-backward",
        Play: "glyphicon glyphicon-play",
        Pause: "glyphicon glyphicon-pause",
        Stop: "glyphicon glyphicon-stop",
        Forward: "glyphicon glyphicon-forward",
        FastForward: "glyphicon glyphicon-fast-forward",
        StepForward: "glyphicon glyphicon-step-forward",
        Eject: "glyphicon glyphicon-eject",
        ChevronLeft: "glyphicon glyphicon-chevron-left",
        ChevronRight: "glyphicon glyphicon-chevron-right",
        PlusSign: "glyphicon glyphicon-plus-sign",
        MinusSign: "glyphicon glyphicon-minus-sign",
        RemoveSign: "glyphicon glyphicon-remove-sign",
        OkSign: "glyphicon glyphicon-ok-sign",
        QuestionSign: "glyphicon glyphicon-question-sign",
        InfoSign: "glyphicon glyphicon-info-sign",
        Screenshot: "glyphicon glyphicon-screenshot",
        RemoveCircle: "glyphicon glyphicon-remove-circle",
        OkCircle: "glyphicon glyphicon-ok-circle",
        BanCircle: "glyphicon glyphicon-ban-circle",
        ArrowLeft: "glyphicon glyphicon-arrow-left",
        ArrowRight: "glyphicon glyphicon-arrow-right",
        ArrowUp: "glyphicon glyphicon-arrow-up",
        ArrowDown: "glyphicon glyphicon-arrow-down",
        ShareAlt: "glyphicon glyphicon-share-alt",
        ResizeFull: "glyphicon glyphicon-resize-full",
        ResizeSmall: "glyphicon glyphicon-resize-small",
        ExclamationSign: "glyphicon glyphicon-exclamation-sign",
        Gift: "glyphicon glyphicon-gift",
        Leaf: "glyphicon glyphicon-leaf",
        Fire: "glyphicon glyphicon-fire",
        EyeOpen: "glyphicon glyphicon-eye-open",
        EyeClose: "glyphicon glyphicon-eye-close",
        WarningSign: "glyphicon glyphicon-warning-sign",
        Plane: "glyphicon glyphicon-plane",
        Calendar: "glyphicon glyphicon-calendar",
        Random: "glyphicon glyphicon-random",
        Comment: "glyphicon glyphicon-comment",
        Magnet: "glyphicon glyphicon-magnet",
        ChevronUp: "glyphicon glyphicon-chevron-up",
        ChevronDown: "glyphicon glyphicon-chevron-down",
        Retweet: "glyphicon glyphicon-retweet",
        ShoppingCart: "glyphicon glyphicon-shopping-cart",
        FolderClose: "glyphicon glyphicon-folder-close",
        FolderOpen: "glyphicon glyphicon-folder-open",
        ResizeVertical: "glyphicon glyphicon-resize-vertical",
        ResizeHorizontal: "glyphicon glyphicon-resize-horizontal",
        Hdd: "glyphicon glyphicon-hdd",
        Bullhorn: "glyphicon glyphicon-bullhorn",
        Bell: "glyphicon glyphicon-bell",
        Certificate: "glyphicon glyphicon-certificate",
        ThumbsUp: "glyphicon glyphicon-thumbs-up",
        ThumbsDown: "glyphicon glyphicon-thumbs-down",
        HandRight: "glyphicon glyphicon-hand-right",
        HandLeft: "glyphicon glyphicon-hand-left",
        HandUp: "glyphicon glyphicon-hand-up",
        HandDown: "glyphicon glyphicon-hand-down",
        CircleArrowRight: "glyphicon glyphicon-circle-arrow-right",
        CircleArrowLeft: "glyphicon glyphicon-circle-arrow-left",
        CircleArrowUp: "glyphicon glyphicon-circle-arrow-up",
        CircleArrowDown: "glyphicon glyphicon-circle-arrow-down",
        Globe: "glyphicon glyphicon-globe",
        Wrench: "glyphicon glyphicon-wrench",
        Tasks: "glyphicon glyphicon-tasks",
        Filter: "glyphicon glyphicon-filter",
        Briefcase: "glyphicon glyphicon-briefcase",
        Fullscreen: "glyphicon glyphicon-fullscreen",
        Dashboard: "glyphicon glyphicon-dashboard",
        Paperclip: "glyphicon glyphicon-paperclip",
        HeartEmpty: "glyphicon glyphicon-heart-empty",
        Link: "glyphicon glyphicon-link",
        Phone: "glyphicon glyphicon-phone",
        Pushpin: "glyphicon glyphicon-pushpin",
        Usd: "glyphicon glyphicon-usd",
        Gbp: "glyphicon glyphicon-gbp",
        Sort: "glyphicon glyphicon-sort",
        SortByAlphabet: "glyphicon glyphicon-sort-by-alphabet",
        SortByAlphabetAlt: "glyphicon glyphicon-sort-by-alphabet-alt",
        SortByOrder: "glyphicon glyphicon-sort-by-order",
        SortByOrderAlt: "glyphicon glyphicon-sort-by-order-alt",
        SortByAttributes: "glyphicon glyphicon-sort-by-attributes",
        SortByAttributesAlt: "glyphicon glyphicon-sort-by-attributes-alt",
        Unchecked: "glyphicon glyphicon-unchecked",
        Expand: "glyphicon glyphicon-expand",
        CollapseDown: "glyphicon glyphicon-collapse-down",
        CollapseUp: "glyphicon glyphicon-collapse-up",
        LogIn: "glyphicon glyphicon-log-in",
        Flash: "glyphicon glyphicon-flash",
        LogOut: "glyphicon glyphicon-log-out",
        NewWindow: "glyphicon glyphicon-new-window",
        Record: "glyphicon glyphicon-record",
        Save: "glyphicon glyphicon-save",
        Open: "glyphicon glyphicon-open",
        Saved: "glyphicon glyphicon-saved",
        Import: "glyphicon glyphicon-import",
        Export: "glyphicon glyphicon-export",
        Send: "glyphicon glyphicon-send",
        FloppyDisk: "glyphicon glyphicon-floppy-disk",
        FloppySaved: "glyphicon glyphicon-floppy-saved",
        FloppyRemove: "glyphicon glyphicon-floppy-remove",
        FloppySave: "glyphicon glyphicon-floppy-save",
        FloppyOpen: "glyphicon glyphicon-floppy-open",
        CreditCard: "glyphicon glyphicon-credit-card",
        Transfer: "glyphicon glyphicon-transfer",
        Cutlery: "glyphicon glyphicon-cutlery",
        Header: "glyphicon glyphicon-header",
        Compressed: "glyphicon glyphicon-compressed",
        Earphone: "glyphicon glyphicon-earphone",
        PhoneAlt: "glyphicon glyphicon-phone-alt",
        Tower: "glyphicon glyphicon-tower",
        Stats: "glyphicon glyphicon-stats",
        SdVideo: "glyphicon glyphicon-sd-video",
        HdVideo: "glyphicon glyphicon-hd-video",
        Subtitles: "glyphicon glyphicon-subtitles",
        SoundStereo: "glyphicon glyphicon-sound-stereo",
        SoundDolby: "glyphicon glyphicon-sound-dolby",
        Sound51: "glyphicon glyphicon-sound-5-1",
        Sound61: "glyphicon glyphicon-sound-6-1",
        Sound71: "glyphicon glyphicon-sound-7-1",
        CopyrightMark: "glyphicon glyphicon-copyright-mark",
        RegistrationMark: "glyphicon glyphicon-registration-mark",
        CloudDownload: "glyphicon glyphicon-cloud-download",
        CloudUpload: "glyphicon glyphicon-cloud-upload",
        TreeConifer: "glyphicon glyphicon-tree-conifer",
        TreeDeciduous: "glyphicon glyphicon-tree-deciduous",
        Cd: "glyphicon glyphicon-cd",
        SaveFile: "glyphicon glyphicon-save-file",
        OpenFile: "glyphicon glyphicon-open-file",
        LevelUp: "glyphicon glyphicon-level-up",
        Copy: "glyphicon glyphicon-copy",
        Paste: "glyphicon glyphicon-paste",
        Alert: "glyphicon glyphicon-alert",
        Equalizer: "glyphicon glyphicon-equalizer",
        King: "glyphicon glyphicon-king",
        Queen: "glyphicon glyphicon-queen",
        Pawn: "glyphicon glyphicon-pawn",
        Bishop: "glyphicon glyphicon-bishop",
        Knight: "glyphicon glyphicon-knight",
        BabyFormula: "glyphicon glyphicon-baby-formula",
        Tent: "glyphicon glyphicon-tent",
        Blackboard: "glyphicon glyphicon-blackboard",
        Bed: "glyphicon glyphicon-bed",
        Apple: "glyphicon glyphicon-apple",
        Erase: "glyphicon glyphicon-erase",
        Hourglass: "glyphicon glyphicon-hourglass",
        Lamp: "glyphicon glyphicon-lamp",
        Duplicate: "glyphicon glyphicon-duplicate",
        PiggyBank: "glyphicon glyphicon-piggy-bank",
        Scissors: "glyphicon glyphicon-scissors",
        Bitcoin: "glyphicon glyphicon-bitcoin",
        Btc: "glyphicon glyphicon-btc",
        Xbt: "glyphicon glyphicon-xbt",
        Yen: "glyphicon glyphicon-yen",
        Jpy: "glyphicon glyphicon-jpy",
        Ruble: "glyphicon glyphicon-ruble",
        Rub: "glyphicon glyphicon-rub",
        Scale: "glyphicon glyphicon-scale",
        IceLolly: "glyphicon glyphicon-ice-lolly",
        IceLollyTasted: "glyphicon glyphicon-ice-lolly-tasted",
        Education: "glyphicon glyphicon-education",
        OptionHorizontal: "glyphicon glyphicon-option-horizontal",
        OptionVertical: "glyphicon glyphicon-option-vertical",
        MenuHamburger: "glyphicon glyphicon-menu-hamburger",
        ModalWindow: "glyphicon glyphicon-modal-window",
        Oil: "glyphicon glyphicon-oil",
        Grain: "glyphicon glyphicon-grain",
        Sunglasses: "glyphicon glyphicon-sunglasses",
        TextSize: "glyphicon glyphicon-text-size",
        TextColor: "glyphicon glyphicon-text-color",
        TextBackground: "glyphicon glyphicon-text-background",
        ObjectAlignTop: "glyphicon glyphicon-object-align-top",
        ObjectAlignBottom: "glyphicon glyphicon-object-align-bottom",
        ObjectAlignHorizontal: "glyphicon glyphicon-object-align-horizontal",
        ObjectAlignLeft: "glyphicon glyphicon-object-align-left",
        ObjectAlignVertical: "glyphicon glyphicon-object-align-vertical",
        ObjectAlignRight: "glyphicon glyphicon-object-align-right",
        TriangleRight: "glyphicon glyphicon-triangle-right",
        TriangleLeft: "glyphicon glyphicon-triangle-left",
        TriangleBottom: "glyphicon glyphicon-triangle-bottom",
        TriangleTop: "glyphicon glyphicon-triangle-top",
        Console: "glyphicon glyphicon-console",
        Superscript: "glyphicon glyphicon-superscript",
        Subscript: "glyphicon glyphicon-subscript",
        MenuLeft: "glyphicon glyphicon-menu-left",
        MenuRight: "glyphicon glyphicon-menu-right",
        MenuDown: "glyphicon glyphicon-menu-down",
        MenuUp: "glyphicon glyphicon-menu-up"
    },
    FontAwesome: {
		_500Px: "fa fa-500px",
		Amazon: "fa fa-amazon",
		BalanceScale: "fa fa-balance-scale",
		Battery0: "fa fa-battery-0",
		Battery1: "fa fa-battery-1",
		Battery2: "fa fa-battery-2",
		Battery3: "fa fa-battery-3",
		Battery4: "fa fa-battery-4",
		BatteryEmpty: "fa fa-battery-empty",
		BatteryFull: "fa fa-battery-full",
		BatteryHalf: "fa fa-battery-half",
		BatteryQuarter: "fa fa-battery-quarter",
		BatteryThreeQuarters: "fa fa-battery-three-quarters",
		BlackTie: "fa fa-black-tie",
		CalendarCheckO: "fa fa-calendar-check-o",
		CalendarMinusO: "fa fa-calendar-minus-o",
		CalendarPlusO: "fa fa-calendar-plus-o",
		CalendarTimesO: "fa fa-calendar-times-o",
		CcDinersClub: "fa fa-cc-diners-club",
		CcJcb: "fa fa-cc-jcb",
		Chrome: "fa fa-chrome",
		Clone: "fa fa-clone",
		Commenting: "fa fa-commenting",
		CommentingO: "fa fa-commenting-o",
		Contao: "fa fa-contao",
		CreativeCommons: "fa fa-creative-commons",
		Expeditedssl: "fa fa-expeditedssl",
		Firefox: "fa fa-firefox",
		Fonticons: "fa fa-fonticons",
		Genderless: "fa fa-genderless",
		GetPocket: "fa fa-get-pocket",
		Gg: "fa fa-gg",
		GgCircle: "fa fa-gg-circle",
		HandGrabO: "fa fa-hand-grab-o",
		HandLizardO: "fa fa-hand-lizard-o",
		HandPaperO: "fa fa-hand-paper-o",
		HandPeaceO: "fa fa-hand-peace-o",
		HandPointerO: "fa fa-hand-pointer-o",
		HandRockO: "fa fa-hand-rock-o",
		HandScissorsO: "fa fa-hand-scissors-o",
		HandSpockO: "fa fa-hand-spock-o",
		HandStopO: "fa fa-hand-stop-o",
		Hourglass: "fa fa-hourglass",
		Hourglass1: "fa fa-hourglass-1",
		Hourglass2: "fa fa-hourglass-2",
		Hourglass3: "fa fa-hourglass-3",
		HourglassEnd: "fa fa-hourglass-end",
		HourglassHalf: "fa fa-hourglass-half",
		HourglassO: "fa fa-hourglass-o",
		HourglassStart: "fa fa-hourglass-start",
		Houzz: "fa fa-houzz",
		ICursor: "fa fa-i-cursor",
		Industry: "fa fa-industry",
		InternetExplorer: "fa fa-internet-explorer",
		Map: "fa fa-map",
		MapO: "fa fa-map-o",
		MapPin: "fa fa-map-pin",
		MapSigns: "fa fa-map-signs",
		MousePointer: "fa fa-mouse-pointer",
		ObjectGroup: "fa fa-object-group",
		ObjectUngroup: "fa fa-object-ungroup",
		Odnoklassniki: "fa fa-odnoklassniki",
		OdnoklassnikiSquare: "fa fa-odnoklassniki-square",
		Opencart: "fa fa-opencart",
		Opera: "fa fa-opera",
		OptinMonster: "fa fa-optin-monster",
		Registered: "fa fa-registered",
		Safari: "fa fa-safari",
		StickyNote: "fa fa-sticky-note",
		StickyNoteO: "fa fa-sticky-note-o",
		Television: "fa fa-television",
		Trademark: "fa fa-trademark",
		Tripadvisor: "fa fa-tripadvisor",
		Tv: "fa fa-tv",
		Vimeo: "fa fa-vimeo",
		WikipediaW: "fa fa-wikipedia-w",
		YCombinator: "fa fa-y-combinator",
		Yc: "fa fa-yc",
		Adjust: "fa fa-adjust",
		Anchor: "fa fa-anchor",
		Archive: "fa fa-archive",
		AreaChart: "fa fa-area-chart",
		Arrows: "fa fa-arrows",
		ArrowsH: "fa fa-arrows-h",
		ArrowsV: "fa fa-arrows-v",
		Asterisk: "fa fa-asterisk",
		At: "fa fa-at",
		Automobile: "fa fa-automobile",
		Ban: "fa fa-ban",
		Bank: "fa fa-bank",
		BarChart: "fa fa-bar-chart",
		BarChartO: "fa fa-bar-chart-o",
		Barcode: "fa fa-barcode",
		Bars: "fa fa-bars",
		Bed: "fa fa-bed",
		Beer: "fa fa-beer",
		Bell: "fa fa-bell",
		BellO: "fa fa-bell-o",
		BellSlash: "fa fa-bell-slash",
		BellSlashO: "fa fa-bell-slash-o",
		Bicycle: "fa fa-bicycle",
		Binoculars: "fa fa-binoculars",
		BirthdayCake: "fa fa-birthday-cake",
		Bolt: "fa fa-bolt",
		Bomb: "fa fa-bomb",
		Book: "fa fa-book",
		Bookmark: "fa fa-bookmark",
		BookmarkO: "fa fa-bookmark-o",
		Briefcase: "fa fa-briefcase",
		Bug: "fa fa-bug",
		Building: "fa fa-building",
		BuildingO: "fa fa-building-o",
		Bullhorn: "fa fa-bullhorn",
		Bullseye: "fa fa-bullseye",
		Bus: "fa fa-bus",
		Cab: "fa fa-cab",
		Calculator: "fa fa-calculator",
		Calendar: "fa fa-calendar",
		CalendarO: "fa fa-calendar-o",
		Camera: "fa fa-camera",
		CameraRetro: "fa fa-camera-retro",
		Car: "fa fa-car",
		CaretSquareODown: "fa fa-caret-square-o-down",
		CaretSquareOLeft: "fa fa-caret-square-o-left",
		CaretSquareORight: "fa fa-caret-square-o-right",
		CaretSquareOUp: "fa fa-caret-square-o-up",
		CartArrowDown: "fa fa-cart-arrow-down",
		CartPlus: "fa fa-cart-plus",
		Cc: "fa fa-cc",
		Certificate: "fa fa-certificate",
		Check: "fa fa-check",
		CheckCircle: "fa fa-check-circle",
		CheckCircleO: "fa fa-check-circle-o",
		CheckSquare: "fa fa-check-square",
		CheckSquareO: "fa fa-check-square-o",
		Child: "fa fa-child",
		Circle: "fa fa-circle",
		CircleO: "fa fa-circle-o",
		CircleONotch: "fa fa-circle-o-notch",
		CircleThin: "fa fa-circle-thin",
		ClockO: "fa fa-clock-o",
		Close: "fa fa-close",
		Cloud: "fa fa-cloud",
		CloudDownload: "fa fa-cloud-download",
		CloudUpload: "fa fa-cloud-upload",
		Code: "fa fa-code",
		CodeFork: "fa fa-code-fork",
		Coffee: "fa fa-coffee",
		Cog: "fa fa-cog",
		Cogs: "fa fa-cogs",
		Comment: "fa fa-comment",
		CommentO: "fa fa-comment-o",
		Comments: "fa fa-comments",
		CommentsO: "fa fa-comments-o",
		Compass: "fa fa-compass",
		Copyright: "fa fa-copyright",
		CreditCard: "fa fa-credit-card",
		Crop: "fa fa-crop",
		Crosshairs: "fa fa-crosshairs",
		Cube: "fa fa-cube",
		Cubes: "fa fa-cubes",
		Cutlery: "fa fa-cutlery",
		Dashboard: "fa fa-dashboard",
		Database: "fa fa-database",
		Desktop: "fa fa-desktop",
		Diamond: "fa fa-diamond",
		DotCircleO: "fa fa-dot-circle-o",
		Download: "fa fa-download",
		Edit: "fa fa-edit",
		EllipsisH: "fa fa-ellipsis-h",
		EllipsisV: "fa fa-ellipsis-v",
		Envelope: "fa fa-envelope",
		EnvelopeO: "fa fa-envelope-o",
		EnvelopeSquare: "fa fa-envelope-square",
		Eraser: "fa fa-eraser",
		Exchange: "fa fa-exchange",
		Exclamation: "fa fa-exclamation",
		ExclamationCircle: "fa fa-exclamation-circle",
		ExclamationTriangle: "fa fa-exclamation-triangle",
		ExternalLink: "fa fa-external-link",
		ExternalLinkSquare: "fa fa-external-link-square",
		Eye: "fa fa-eye",
		EyeSlash: "fa fa-eye-slash",
		Eyedropper: "fa fa-eyedropper",
		Fax: "fa fa-fax",
		Feed: "fa fa-feed",
		Female: "fa fa-female",
		FighterJet: "fa fa-fighter-jet",
		FileArchiveO: "fa fa-file-archive-o",
		FileAudioO: "fa fa-file-audio-o",
		FileCodeO: "fa fa-file-code-o",
		FileExcelO: "fa fa-file-excel-o",
		FileImageO: "fa fa-file-image-o",
		FileMovieO: "fa fa-file-movie-o",
		FilePdfO: "fa fa-file-pdf-o",
		FilePhotoO: "fa fa-file-photo-o",
		FilePictureO: "fa fa-file-picture-o",
		FilePowerpointO: "fa fa-file-powerpoint-o",
		FileSoundO: "fa fa-file-sound-o",
		FileVideoO: "fa fa-file-video-o",
		FileWordO: "fa fa-file-word-o",
		FileZipO: "fa fa-file-zip-o",
		Film: "fa fa-film",
		Filter: "fa fa-filter",
		Fire: "fa fa-fire",
		FireExtinguisher: "fa fa-fire-extinguisher",
		Flag: "fa fa-flag",
		FlagCheckered: "fa fa-flag-checkered",
		FlagO: "fa fa-flag-o",
		Flash: "fa fa-flash",
		Flask: "fa fa-flask",
		Folder: "fa fa-folder",
		FolderO: "fa fa-folder-o",
		FolderOpen: "fa fa-folder-open",
		FolderOpenO: "fa fa-folder-open-o",
		FrownO: "fa fa-frown-o",
		FutbolO: "fa fa-futbol-o",
		Gamepad: "fa fa-gamepad",
		Gavel: "fa fa-gavel",
		Gear: "fa fa-gear",
		Gears: "fa fa-gears",
		Gift: "fa fa-gift",
		Glass: "fa fa-glass",
		Globe: "fa fa-globe",
		GraduationCap: "fa fa-graduation-cap",
		Group: "fa fa-group",
		HddO: "fa fa-hdd-o",
		Headphones: "fa fa-headphones",
		Heart: "fa fa-heart",
		HeartO: "fa fa-heart-o",
		Heartbeat: "fa fa-heartbeat",
		History: "fa fa-history",
		Home: "fa fa-home",
		Hotel: "fa fa-hotel",
		Image: "fa fa-image",
		Inbox: "fa fa-inbox",
		Info: "fa fa-info",
		InfoCircle: "fa fa-info-circle",
		Institution: "fa fa-institution",
		Key: "fa fa-key",
		KeyboardO: "fa fa-keyboard-o",
		Language: "fa fa-language",
		Laptop: "fa fa-laptop",
		Leaf: "fa fa-leaf",
		Legal: "fa fa-legal",
		LemonO: "fa fa-lemon-o",
		LevelDown: "fa fa-level-down",
		LevelUp: "fa fa-level-up",
		LifeBouy: "fa fa-life-bouy",
		LifeBuoy: "fa fa-life-buoy",
		LifeRing: "fa fa-life-ring",
		LifeSaver: "fa fa-life-saver",
		LightbulbO: "fa fa-lightbulb-o",
		LineChart: "fa fa-line-chart",
		LocationArrow: "fa fa-location-arrow",
		Lock: "fa fa-lock",
		Magic: "fa fa-magic",
		Magnet: "fa fa-magnet",
		MailForward: "fa fa-mail-forward",
		MailReply: "fa fa-mail-reply",
		MailReplyAll: "fa fa-mail-reply-all",
		Male: "fa fa-male",
		MapMarker: "fa fa-map-marker",
		MehO: "fa fa-meh-o",
		Microphone: "fa fa-microphone",
		MicrophoneSlash: "fa fa-microphone-slash",
		Minus: "fa fa-minus",
		MinusCircle: "fa fa-minus-circle",
		MinusSquare: "fa fa-minus-square",
		MinusSquareO: "fa fa-minus-square-o",
		Mobile: "fa fa-mobile",
		MobilePhone: "fa fa-mobile-phone",
		Money: "fa fa-money",
		MoonO: "fa fa-moon-o",
		MortarBoard: "fa fa-mortar-board",
		Motorcycle: "fa fa-motorcycle",
		Music: "fa fa-music",
		Navicon: "fa fa-navicon",
		NewspaperO: "fa fa-newspaper-o",
		PaintBrush: "fa fa-paint-brush",
		PaperPlane: "fa fa-paper-plane",
		PaperPlaneO: "fa fa-paper-plane-o",
		Paw: "fa fa-paw",
		Pencil: "fa fa-pencil",
		PencilSquare: "fa fa-pencil-square",
		PencilSquareO: "fa fa-pencil-square-o",
		Phone: "fa fa-phone",
		PhoneSquare: "fa fa-phone-square",
		Photo: "fa fa-photo",
		PictureO: "fa fa-picture-o",
		PieChart: "fa fa-pie-chart",
		Plane: "fa fa-plane",
		Plug: "fa fa-plug",
		Plus: "fa fa-plus",
		PlusCircle: "fa fa-plus-circle",
		PlusSquare: "fa fa-plus-square",
		PlusSquareO: "fa fa-plus-square-o",
		PowerOff: "fa fa-power-off",
		Print: "fa fa-print",
		PuzzlePiece: "fa fa-puzzle-piece",
		Qrcode: "fa fa-qrcode",
		Question: "fa fa-question",
		QuestionCircle: "fa fa-question-circle",
		QuoteLeft: "fa fa-quote-left",
		QuoteRight: "fa fa-quote-right",
		Random: "fa fa-random",
		Recycle: "fa fa-recycle",
		Refresh: "fa fa-refresh",
		Remove: "fa fa-remove",
		Reorder: "fa fa-reorder",
		Reply: "fa fa-reply",
		ReplyAll: "fa fa-reply-all",
		Retweet: "fa fa-retweet",
		Road: "fa fa-road",
		Rocket: "fa fa-rocket",
		Rss: "fa fa-rss",
		RssSquare: "fa fa-rss-square",
		Search: "fa fa-search",
		SearchMinus: "fa fa-search-minus",
		SearchPlus: "fa fa-search-plus",
		Send: "fa fa-send",
		SendO: "fa fa-send-o",
		Server: "fa fa-server",
		Share: "fa fa-share",
		ShareAlt: "fa fa-share-alt",
		ShareAltSquare: "fa fa-share-alt-square",
		ShareSquare: "fa fa-share-square",
		ShareSquareO: "fa fa-share-square-o",
		Shield: "fa fa-shield",
		Ship: "fa fa-ship",
		ShoppingCart: "fa fa-shopping-cart",
		SignIn: "fa fa-sign-in",
		SignOut: "fa fa-sign-out",
		Signal: "fa fa-signal",
		Sitemap: "fa fa-sitemap",
		Sliders: "fa fa-sliders",
		SmileO: "fa fa-smile-o",
		SoccerBallO: "fa fa-soccer-ball-o",
		Sort: "fa fa-sort",
		SortAlphaAsc: "fa fa-sort-alpha-asc",
		SortAlphaDesc: "fa fa-sort-alpha-desc",
		SortAmountAsc: "fa fa-sort-amount-asc",
		SortAmountDesc: "fa fa-sort-amount-desc",
		SortAsc: "fa fa-sort-asc",
		SortDesc: "fa fa-sort-desc",
		SortDown: "fa fa-sort-down",
		SortNumericAsc: "fa fa-sort-numeric-asc",
		SortNumericDesc: "fa fa-sort-numeric-desc",
		SortUp: "fa fa-sort-up",
		SpaceShuttle: "fa fa-space-shuttle",
		Spinner: "fa fa-spinner",
		Spoon: "fa fa-spoon",
		Square: "fa fa-square",
		SquareO: "fa fa-square-o",
		Star: "fa fa-star",
		StarHalf: "fa fa-star-half",
		StarHalfEmpty: "fa fa-star-half-empty",
		StarHalfFull: "fa fa-star-half-full",
		StarHalfO: "fa fa-star-half-o",
		StarO: "fa fa-star-o",
		StreetView: "fa fa-street-view",
		Suitcase: "fa fa-suitcase",
		SunO: "fa fa-sun-o",
		Support: "fa fa-support",
		Tablet: "fa fa-tablet",
		Tachometer: "fa fa-tachometer",
		Tag: "fa fa-tag",
		Tags: "fa fa-tags",
		Tasks: "fa fa-tasks",
		Taxi: "fa fa-taxi",
		Terminal: "fa fa-terminal",
		ThumbTack: "fa fa-thumb-tack",
		ThumbsDown: "fa fa-thumbs-down",
		ThumbsODown: "fa fa-thumbs-o-down",
		ThumbsOUp: "fa fa-thumbs-o-up",
		ThumbsUp: "fa fa-thumbs-up",
		Ticket: "fa fa-ticket",
		Times: "fa fa-times",
		TimesCircle: "fa fa-times-circle",
		TimesCircleO: "fa fa-times-circle-o",
		Tint: "fa fa-tint",
		ToggleDown: "fa fa-toggle-down",
		ToggleLeft: "fa fa-toggle-left",
		ToggleOff: "fa fa-toggle-off",
		ToggleOn: "fa fa-toggle-on",
		ToggleRight: "fa fa-toggle-right",
		ToggleUp: "fa fa-toggle-up",
		Trash: "fa fa-trash",
		TrashO: "fa fa-trash-o",
		Tree: "fa fa-tree",
		Trophy: "fa fa-trophy",
		Truck: "fa fa-truck",
		Tty: "fa fa-tty",
		Umbrella: "fa fa-umbrella",
		University: "fa fa-university",
		Unlock: "fa fa-unlock",
		UnlockAlt: "fa fa-unlock-alt",
		Unsorted: "fa fa-unsorted",
		Upload: "fa fa-upload",
		User: "fa fa-user",
		UserPlus: "fa fa-user-plus",
		UserSecret: "fa fa-user-secret",
		UserTimes: "fa fa-user-times",
		Users: "fa fa-users",
		VideoCamera: "fa fa-video-camera",
		VolumeDown: "fa fa-volume-down",
		VolumeOff: "fa fa-volume-off",
		VolumeUp: "fa fa-volume-up",
		Warning: "fa fa-warning",
		Wheelchair: "fa fa-wheelchair",
		Wifi: "fa fa-wifi",
		Wrench: "fa fa-wrench",
		HandODown: "fa fa-hand-o-down",
		HandOLeft: "fa fa-hand-o-left",
		HandORight: "fa fa-hand-o-right",
		HandOUp: "fa fa-hand-o-up",
		Ambulance: "fa fa-ambulance",
		Subway: "fa fa-subway",
		Train: "fa fa-train",
		Intersex: "fa fa-intersex",
		Mars: "fa fa-mars",
		MarsDouble: "fa fa-mars-double",
		MarsStroke: "fa fa-mars-stroke",
		MarsStrokeH: "fa fa-mars-stroke-h",
		MarsStrokeV: "fa fa-mars-stroke-v",
		Mercury: "fa fa-mercury",
		Neuter: "fa fa-neuter",
		Transgender: "fa fa-transgender",
		TransgenderAlt: "fa fa-transgender-alt",
		Venus: "fa fa-venus",
		VenusDouble: "fa fa-venus-double",
		VenusMars: "fa fa-venus-mars",
		File: "fa fa-file",
		FileO: "fa fa-file-o",
		FileText: "fa fa-file-text",
		FileTextO: "fa fa-file-text-o",
		CcAmex: "fa fa-cc-amex",
		CcDiscover: "fa fa-cc-discover",
		CcMastercard: "fa fa-cc-mastercard",
		CcPaypal: "fa fa-cc-paypal",
		CcStripe: "fa fa-cc-stripe",
		CcVisa: "fa fa-cc-visa",
		GoogleWallet: "fa fa-google-wallet",
		Paypal: "fa fa-paypal",
		Bitcoin: "fa fa-bitcoin",
		Btc: "fa fa-btc",
		Cny: "fa fa-cny",
		Dollar: "fa fa-dollar",
		Eur: "fa fa-eur",
		Euro: "fa fa-euro",
		Gbp: "fa fa-gbp",
		Ils: "fa fa-ils",
		Inr: "fa fa-inr",
		Jpy: "fa fa-jpy",
		Krw: "fa fa-krw",
		Rmb: "fa fa-rmb",
		Rouble: "fa fa-rouble",
		Rub: "fa fa-rub",
		Ruble: "fa fa-ruble",
		Rupee: "fa fa-rupee",
		Shekel: "fa fa-shekel",
		Sheqel: "fa fa-sheqel",
		Try: "fa fa-try",
		TurkishLira: "fa fa-turkish-lira",
		Usd: "fa fa-usd",
		Won: "fa fa-won",
		Yen: "fa fa-yen",
		AlignCenter: "fa fa-align-center",
		AlignJustify: "fa fa-align-justify",
		AlignLeft: "fa fa-align-left",
		AlignRight: "fa fa-align-right",
		Bold: "fa fa-bold",
		Chain: "fa fa-chain",
		ChainBroken: "fa fa-chain-broken",
		Clipboard: "fa fa-clipboard",
		Columns: "fa fa-columns",
		Copy: "fa fa-copy",
		Cut: "fa fa-cut",
		Dedent: "fa fa-dedent",
		FilesO: "fa fa-files-o",
		FloppyO: "fa fa-floppy-o",
		Font: "fa fa-font",
		Header: "fa fa-header",
		Indent: "fa fa-indent",
		Italic: "fa fa-italic",
		Link: "fa fa-link",
		List: "fa fa-list",
		ListAlt: "fa fa-list-alt",
		ListOl: "fa fa-list-ol",
		ListUl: "fa fa-list-ul",
		Outdent: "fa fa-outdent",
		Paperclip: "fa fa-paperclip",
		Paragraph: "fa fa-paragraph",
		Paste: "fa fa-paste",
		Repeat: "fa fa-repeat",
		RotateLeft: "fa fa-rotate-left",
		RotateRight: "fa fa-rotate-right",
		Save: "fa fa-save",
		Scissors: "fa fa-scissors",
		Strikethrough: "fa fa-strikethrough",
		Subscript: "fa fa-subscript",
		Superscript: "fa fa-superscript",
		Table: "fa fa-table",
		TextHeight: "fa fa-text-height",
		TextWidth: "fa fa-text-width",
		Th: "fa fa-th",
		ThLarge: "fa fa-th-large",
		ThList: "fa fa-th-list",
		Underline: "fa fa-underline",
		Undo: "fa fa-undo",
		Unlink: "fa fa-unlink",
		AngleDoubleDown: "fa fa-angle-double-down",
		AngleDoubleLeft: "fa fa-angle-double-left",
		AngleDoubleRight: "fa fa-angle-double-right",
		AngleDoubleUp: "fa fa-angle-double-up",
		AngleDown: "fa fa-angle-down",
		AngleLeft: "fa fa-angle-left",
		AngleRight: "fa fa-angle-right",
		AngleUp: "fa fa-angle-up",
		ArrowCircleDown: "fa fa-arrow-circle-down",
		ArrowCircleLeft: "fa fa-arrow-circle-left",
		ArrowCircleODown: "fa fa-arrow-circle-o-down",
		ArrowCircleOLeft: "fa fa-arrow-circle-o-left",
		ArrowCircleORight: "fa fa-arrow-circle-o-right",
		ArrowCircleOUp: "fa fa-arrow-circle-o-up",
		ArrowCircleRight: "fa fa-arrow-circle-right",
		ArrowCircleUp: "fa fa-arrow-circle-up",
		ArrowDown: "fa fa-arrow-down",
		ArrowLeft: "fa fa-arrow-left",
		ArrowRight: "fa fa-arrow-right",
		ArrowUp: "fa fa-arrow-up",
		ArrowsAlt: "fa fa-arrows-alt",
		CaretDown: "fa fa-caret-down",
		CaretLeft: "fa fa-caret-left",
		CaretRight: "fa fa-caret-right",
		CaretUp: "fa fa-caret-up",
		ChevronCircleDown: "fa fa-chevron-circle-down",
		ChevronCircleLeft: "fa fa-chevron-circle-left",
		ChevronCircleRight: "fa fa-chevron-circle-right",
		ChevronCircleUp: "fa fa-chevron-circle-up",
		ChevronDown: "fa fa-chevron-down",
		ChevronLeft: "fa fa-chevron-left",
		ChevronRight: "fa fa-chevron-right",
		ChevronUp: "fa fa-chevron-up",
		LongArrowDown: "fa fa-long-arrow-down",
		LongArrowLeft: "fa fa-long-arrow-left",
		LongArrowRight: "fa fa-long-arrow-right",
		LongArrowUp: "fa fa-long-arrow-up",
		Backward: "fa fa-backward",
		Compress: "fa fa-compress",
		Eject: "fa fa-eject",
		Expand: "fa fa-expand",
		FastBackward: "fa fa-fast-backward",
		FastForward: "fa fa-fast-forward",
		Forward: "fa fa-forward",
		Pause: "fa fa-pause",
		Play: "fa fa-play",
		PlayCircle: "fa fa-play-circle",
		PlayCircleO: "fa fa-play-circle-o",
		StepBackward: "fa fa-step-backward",
		StepForward: "fa fa-step-forward",
		Stop: "fa fa-stop",
		YoutubePlay: "fa fa-youtube-play",
		Adn: "fa fa-adn",
		Android: "fa fa-android",
		Angellist: "fa fa-angellist",
		Apple: "fa fa-apple",
		Behance: "fa fa-behance",
		BehanceSquare: "fa fa-behance-square",
		Bitbucket: "fa fa-bitbucket",
		BitbucketSquare: "fa fa-bitbucket-square",
		Buysellads: "fa fa-buysellads",
		Codepen: "fa fa-codepen",
		Connectdevelop: "fa fa-connectdevelop",
		Css3: "fa fa-css3",
		Dashcube: "fa fa-dashcube",
		Delicious: "fa fa-delicious",
		Deviantart: "fa fa-deviantart",
		Digg: "fa fa-digg",
		Dribbble: "fa fa-dribbble",
		Dropbox: "fa fa-dropbox",
		Drupal: "fa fa-drupal",
		Empire: "fa fa-empire",
		Facebook: "fa fa-facebook",
		FacebookF: "fa fa-facebook-f",
		FacebookOfficial: "fa fa-facebook-official",
		FacebookSquare: "fa fa-facebook-square",
		Flickr: "fa fa-flickr",
		Forumbee: "fa fa-forumbee",
		Foursquare: "fa fa-foursquare",
		Ge: "fa fa-ge",
		Git: "fa fa-git",
		GitSquare: "fa fa-git-square",
		Github: "fa fa-github",
		GithubAlt: "fa fa-github-alt",
		GithubSquare: "fa fa-github-square",
		Gittip: "fa fa-gittip",
		Google: "fa fa-google",
		GooglePlus: "fa fa-google-plus",
		GooglePlusSquare: "fa fa-google-plus-square",
		Gratipay: "fa fa-gratipay",
		HackerNews: "fa fa-hacker-news",
		Html5: "fa fa-html5",
		Instagram: "fa fa-instagram",
		Ioxhost: "fa fa-ioxhost",
		Joomla: "fa fa-joomla",
		Jsfiddle: "fa fa-jsfiddle",
		Lastfm: "fa fa-lastfm",
		LastfmSquare: "fa fa-lastfm-square",
		Leanpub: "fa fa-leanpub",
		Linkedin: "fa fa-linkedin",
		LinkedinSquare: "fa fa-linkedin-square",
		Linux: "fa fa-linux",
		Maxcdn: "fa fa-maxcdn",
		Meanpath: "fa fa-meanpath",
		Medium: "fa fa-medium",
		Openid: "fa fa-openid",
		Pagelines: "fa fa-pagelines",
		PiedPiper: "fa fa-pied-piper",
		PiedPiperAlt: "fa fa-pied-piper-alt",
		Pinterest: "fa fa-pinterest",
		PinterestP: "fa fa-pinterest-p",
		PinterestSquare: "fa fa-pinterest-square",
		Qq: "fa fa-qq",
		Ra: "fa fa-ra",
		Rebel: "fa fa-rebel",
		Reddit: "fa fa-reddit",
		RedditSquare: "fa fa-reddit-square",
		Renren: "fa fa-renren",
		Sellsy: "fa fa-sellsy",
		Shirtsinbulk: "fa fa-shirtsinbulk",
		Simplybuilt: "fa fa-simplybuilt",
		Skyatlas: "fa fa-skyatlas",
		Skype: "fa fa-skype",
		Slack: "fa fa-slack",
		Slideshare: "fa fa-slideshare",
		Soundcloud: "fa fa-soundcloud",
		Spotify: "fa fa-spotify",
		StackExchange: "fa fa-stack-exchange",
		StackOverflow: "fa fa-stack-overflow",
		Steam: "fa fa-steam",
		SteamSquare: "fa fa-steam-square",
		Stumbleupon: "fa fa-stumbleupon",
		StumbleuponCircle: "fa fa-stumbleupon-circle",
		TencentWeibo: "fa fa-tencent-weibo",
		Trello: "fa fa-trello",
		Tumblr: "fa fa-tumblr",
		TumblrSquare: "fa fa-tumblr-square",
		Twitch: "fa fa-twitch",
		Twitter: "fa fa-twitter",
		TwitterSquare: "fa fa-twitter-square",
		Viacoin: "fa fa-viacoin",
		VimeoSquare: "fa fa-vimeo-square",
		Vine: "fa fa-vine",
		Vk: "fa fa-vk",
		Wechat: "fa fa-wechat",
		Weibo: "fa fa-weibo",
		Weixin: "fa fa-weixin",
		Whatsapp: "fa fa-whatsapp",
		Windows: "fa fa-windows",
		Wordpress: "fa fa-wordpress",
		Xing: "fa fa-xing",
		XingSquare: "fa fa-xing-square",
		YCombinatorSquare: "fa fa-y-combinator-square",
		Yahoo: "fa fa-yahoo",
		YcSquare: "fa fa-yc-square",
		Yelp: "fa fa-yelp",
		Youtube: "fa fa-youtube",
		YoutubeSquare: "fa fa-youtube-square",
		HSquare: "fa fa-h-square",
		HospitalO: "fa fa-hospital-o",
		Medkit: "fa fa-medkit",
		Stethoscope: "fa fa-stethoscope",
		UserMd: "fa fa-user-md",
    }
};
